# Changelog
All notable changes to this project will be documented in this file.

The format is based on Keep a Changelog and this project adheres to Semantic Versioning.

## 0.1.2 - 2026-01-01
- Add changelog.

## 0.1.1 - 2026-01-01
- Initial public release.
